public inbox for linux-omap@vger.kernel.org
 help / color / mirror / Atom feed
From: Tony Lindgren <tony@atomide.com>
To: linux-omap-open-source@linux.omap.com
Subject: [PATCH 41/52] musb_hdrc: Search and replace bDesiredMode with desired_mode
Date: Mon, 13 Aug 2007 06:49:16 -0700	[thread overview]
Message-ID: <11870130793168-git-send-email-tony@atomide.com> (raw)
In-Reply-To: <11870130771666-git-send-email-tony@atomide.com>

Search and replace bDesiredMode with desired_mode

Signed-off-by: Tony Lindgren <tony@atomide.com>
---
 drivers/usb/musb/dma.h           |    4 ++--
 drivers/usb/musb/musb_gadget.c   |   20 ++++++++++----------
 drivers/usb/musb/musb_host.c     |   18 +++++++++---------
 drivers/usb/musb/musbhsdma.c     |    4 ++--
 drivers/usb/musb/tusb6010_omap.c |    2 +-
 5 files changed, 24 insertions(+), 24 deletions(-)

--- a/drivers/usb/musb/musb_gadget.c
+++ b/drivers/usb/musb/musb_gadget.c
@@ -306,16 +306,16 @@ static void txstate(struct musb *musb, struct musb_request *req)
 			request_size = min(pRequest->length,
 						musb_ep->dma->max_len);
 			if (request_size <= musb_ep->wPacketSize)
-				musb_ep->dma->bDesiredMode = 0;
+				musb_ep->dma->desired_mode = 0;
 			else
-				musb_ep->dma->bDesiredMode = 1;
+				musb_ep->dma->desired_mode = 1;
 
 			use_dma = use_dma && c->channel_program(
 					musb_ep->dma, musb_ep->wPacketSize,
-					musb_ep->dma->bDesiredMode,
+					musb_ep->dma->desired_mode,
 					pRequest->dma, request_size);
 			if (use_dma) {
-				if (musb_ep->dma->bDesiredMode == 0) {
+				if (musb_ep->dma->desired_mode == 0) {
 					/* ASSERT: DMAENAB is clear */
 					wCsrVal &= ~(MGC_M_TXCSR_AUTOSET |
 							MGC_M_TXCSR_DMAMODE);
@@ -487,7 +487,7 @@ void musb_g_tx(struct musb *musb, u8 epnum)
 							== 0)
 #ifdef CONFIG_USB_INVENTRA_DMA
 					|| (is_dma &&
-						((!dma->bDesiredMode) ||
+						((!dma->desired_mode) ||
 						    (pRequest->actual &
 						    (musb_ep->wPacketSize - 1))))
 #endif
@@ -666,14 +666,14 @@ static void rxstate(struct musb *musb, struct musb_request *req)
 					transfer_size = len;
 #endif
 					if (transfer_size <= musb_ep->wPacketSize)
-						musb_ep->dma->bDesiredMode = 0;
+						musb_ep->dma->desired_mode = 0;
 					else
-						musb_ep->dma->bDesiredMode = 1;
+						musb_ep->dma->desired_mode = 1;
 
 					use_dma = c->channel_program(
 							channel,
 							musb_ep->wPacketSize,
-							channel->bDesiredMode,
+							channel->desired_mode,
 							pRequest->dma
 							+ pRequest->actual,
 							transfer_size);
@@ -701,7 +701,7 @@ static void rxstate(struct musb *musb, struct musb_request *req)
 
 				ret = c->channel_program(channel,
 						musb_ep->wPacketSize,
-						channel->bDesiredMode,
+						channel->desired_mode,
 						dma_addr,
 						fifo_count);
 				if (ret == TRUE)
@@ -805,7 +805,7 @@ void musb_g_rx(struct musb *musb, u8 epnum)
 
 #if defined(CONFIG_USB_INVENTRA_DMA) || defined(CONFIG_USB_TUSB_OMAP_DMA)
 		/* Autoclear doesn't clear RxPktRdy for short packets */
-		if ((dma->bDesiredMode == 0)
+		if ((dma->desired_mode == 0)
 				|| (dma->actual_len
 					& (musb_ep->wPacketSize - 1))) {
 			/* ack the read! */
--- a/drivers/usb/musb/musb_host.c
+++ b/drivers/usb/musb/musb_host.c
@@ -774,12 +774,12 @@ static void musb_ep_program(struct musb *musb, u8 epnum,
 			qh->segsize = min(dwLength, pDmaChannel->max_len);
 
 			if (qh->segsize <= wPacketSize)
-				pDmaChannel->bDesiredMode = 0;
+				pDmaChannel->desired_mode = 0;
 			else
-				pDmaChannel->bDesiredMode = 1;
+				pDmaChannel->desired_mode = 1;
 
 
-			if (pDmaChannel->bDesiredMode == 0) {
+			if (pDmaChannel->desired_mode == 0) {
 				wCsr &= ~(MGC_M_TXCSR_AUTOSET
 					| MGC_M_TXCSR_DMAMODE);
 				wCsr |= (MGC_M_TXCSR_DMAENAB);
@@ -793,7 +793,7 @@ static void musb_ep_program(struct musb *musb, u8 epnum,
 
 			bDmaOk = dma_controller->channel_program(
 					pDmaChannel, wPacketSize,
-					pDmaChannel->bDesiredMode,
+					pDmaChannel->desired_mode,
 					pUrb->transfer_dma,
 					qh->segsize);
 			if (bDmaOk) {
@@ -1569,7 +1569,7 @@ void musb_host_rx(struct musb *musb, u8 epnum)
 
 			c = musb->dma_controller;
 
-			dma->bDesiredMode = 0;
+			dma->desired_mode = 0;
 #ifdef USE_MODE1
 			/* because of the issue below, mode 1 will
 			 * only rarely behave with correct semantics.
@@ -1579,7 +1579,7 @@ void musb_host_rx(struct musb *musb, u8 epnum)
 				&& (pUrb->transfer_buffer_length -
 						pUrb->actual_length)
 					> qh->maxpacket)
-				dma->bDesiredMode = 1;
+				dma->desired_mode = 1;
 #endif
 
 /* Disadvantage of using mode 1:
@@ -1602,7 +1602,7 @@ void musb_host_rx(struct musb *musb, u8 epnum)
 			wVal = musb_readw(epio, MGC_O_HDRC_RXCSR);
 			wVal &= ~MGC_M_RXCSR_H_REQPKT;
 
-			if (dma->bDesiredMode == 0)
+			if (dma->desired_mode == 0)
 				wVal &= ~MGC_M_RXCSR_H_AUTOREQ;
 			else
 				wVal |= MGC_M_RXCSR_H_AUTOREQ;
@@ -1617,10 +1617,10 @@ void musb_host_rx(struct musb *musb, u8 epnum)
 			 */
 			status = c->channel_program(
 				dma, qh->maxpacket,
-				dma->bDesiredMode,
+				dma->desired_mode,
 				pUrb->transfer_dma
 					+ pUrb->actual_length,
-				(dma->bDesiredMode == 0)
+				(dma->desired_mode == 0)
 					? wRxCount
 					: pUrb->transfer_buffer_length);
 
--- a/drivers/usb/musb/musbhsdma.c
+++ b/drivers/usb/musb/musbhsdma.c
@@ -147,7 +147,7 @@ static struct dma_channel* dma_channel_allocate(struct dma_controller *c,
 			pChannel->status = MGC_DMA_STATUS_FREE;
 			pChannel->max_len = 0x10000;
 			/* Tx => mode 1; Rx => mode 0 */
-			pChannel->bDesiredMode = bTransmit;
+			pChannel->desired_mode = bTransmit;
 			pChannel->actual_len = 0;
 			break;
 		}
@@ -348,7 +348,7 @@ static irqreturn_t dma_controller_irq(int irq, void *private_data)
 				/* completed */
 				if ((devctl & MGC_M_DEVCTL_HM)
 				    && (pImplChannel->bTransmit)
-				    && ((pChannel->bDesiredMode == 0)
+				    && ((pChannel->desired_mode == 0)
 					|| (pChannel->actual_len &
 					    (pImplChannel->wMaxPacketSize - 1)))
 				   ) {
--- a/drivers/usb/musb/tusb6010_omap.c
+++ b/drivers/usb/musb/tusb6010_omap.c
@@ -549,7 +549,7 @@ tusb_omap_dma_allocate(struct dma_controller *c,
 	chdat->tusb_dma = tusb_dma;
 
 	channel->max_len = 0x7fffffff;
-	channel->bDesiredMode = 0;
+	channel->desired_mode = 0;
 	channel->actual_len = 0;
 
 	if (dmareq_works()) {
--- a/drivers/usb/musb/dma.h
+++ b/drivers/usb/musb/dma.h
@@ -105,7 +105,7 @@ struct dma_controller;
  *	transaction (typically representing many USB maximum-sized packets)
  * @actual_len: how many bytes have been transferred
  * @status: current channel status (updated e.g. on interrupt)
  * @bDesiredMode: TRUE if mode 1 is desired; FALSE if mode 0 is desired
  *
  * channels are associated with an endpoint for the duration of at least
  * one usb transfer.
@@ -116,7 +116,7 @@ struct dma_channel {
 	size_t			max_len;
 	size_t			actual_len;
 	enum dma_channel_status	status;
-	u8			bDesiredMode;
+	u8			desired_mode;
 };
 
 /*
@@ -105,7 +105,7 @@ struct dma_controller;
  * @actual_len: how many bytes have been transferred
  * @status: current channel status (updated e.g. on interrupt)
- * @bDesiredMode: TRUE if mode 1 is desired; FALSE if mode 0 is desired
+ * @desired_mode: TRUE if mode 1 is desired; FALSE if mode 0 is desired
  *
  * channels are associated with an endpoint for the duration of at least
-- 
1.5.2.3

  reply	other threads:[~2007-08-13 13:49 UTC|newest]

Thread overview: 57+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2007-08-13 13:48 (no subject) Tony Lindgren
2007-08-13 13:48 ` [PATCH 1/52] musb_hdrc: Search and replace pThis with musb Tony Lindgren
2007-08-13 13:48   ` [PATCH 2/52] musb_hdrc: Search and replace pEndPt with hw_ep Tony Lindgren
2007-08-13 13:48     ` [PATCH 3/52] musb_hdrc: Search and replace pEnd with musb_ep when struct musb_ep Tony Lindgren
2007-08-13 13:48       ` [PATCH 4/52] musb_hdrc: Search and replace pEnd with musb_ep when struct musb_hw_ep Tony Lindgren
2007-08-13 13:48         ` [PATCH 5/52] musb_hdrc: Search and replace pRegs with mregs Tony Lindgren
2007-08-13 13:48           ` [PATCH 6/52] musb_hdrc: Search and replace pBase with mbase Tony Lindgren
2007-08-13 13:48             ` [PATCH 7/52] musb_hdrc: Search and replace pSource with src Tony Lindgren
2007-08-13 13:48               ` [PATCH 8/52] musb_hdrc: Search and replace pDest with dst Tony Lindgren
2007-08-13 13:48                 ` [PATCH 9/52] musb_hdrc: Search and replace dwCount with len Tony Lindgren
2007-08-13 13:48                   ` [PATCH 10/52] musb_hdrc: Search and replace wFifoCount with fifo_count Tony Lindgren
2007-08-13 13:48                     ` [PATCH 11/52] musb_hdrc: Search and replace wCount with len Tony Lindgren
2007-08-13 13:48                       ` [PATCH 12/52] musb_hdrc: Search and replace bLocalEnd with epnum Tony Lindgren
2007-08-13 13:48                         ` [PATCH 13/52] musb_hdrc: Search and replace aLocalEnd with endpoints Tony Lindgren
2007-08-13 13:48                           ` [PATCH 14/52] musb_hdrc: Search and replace bEndCount with nr_endpoints Tony Lindgren
2007-08-13 13:48                             ` [PATCH 15/52] musb_hdrc: Search and replace bEndNumber with current_epnum Tony Lindgren
2007-08-13 13:48                               ` [PATCH 16/52] musb_hdrc: Search and replace bEnd0Stage with ep0_stage Tony Lindgren
2007-08-13 13:48                                 ` [PATCH 17/52] musb_hdrc: Search and replace bEnd with epnum Tony Lindgren
2007-08-13 13:48                                   ` [PATCH 18/52] musb_hdrc: Search and replace Lock with lock Tony Lindgren
2007-08-13 13:48                                     ` [PATCH 19/52] musb_hdrc: Search and replace MGC_SelectEnd with musb_ep_select Tony Lindgren
2007-08-13 13:48                                       ` [PATCH 20/52] musb_hdrc: Search and replace _pthis with _musb Tony Lindgren
2007-08-13 13:48                                         ` [PATCH 21/52] musb_hdrc: Search and replace bIsHost with is_host Tony Lindgren
2007-08-13 13:48                                           ` [PATCH 22/52] musb_hdrc: Get rid of old unused MUSB_EpFifoDescriptor Tony Lindgren
2007-08-13 13:48                                             ` [PATCH 23/52] musb_hdrc: Search and replace bIsSharedFifo with is_shared_fifo Tony Lindgren
2007-08-13 13:48                                               ` [PATCH 24/52] musb_hdrc: Search and replace wMaxPacketSizeTx with max_packet_sz_tx Tony Lindgren
2007-08-13 13:49                                                 ` [PATCH 25/52] musb_hdrc: Search and replace wMaxPacketSizeRx with max_packet_sz_rx Tony Lindgren
2007-08-13 13:49                                                   ` [PATCH 26/52] musb_hdrc: Search and replace pDmaController with dma_controller Tony Lindgren
2007-08-13 13:49                                                     ` [PATCH 27/52] musb_hdrc: Search and replace bIsMultipoint with is_multipoint Tony Lindgren
2007-08-13 13:49                                                       ` [PATCH 28/52] musb_hdrc: Search and replace bIgnoreDisconnect with ignore_disconnect Tony Lindgren
2007-08-13 13:49                                                         ` [PATCH 29/52] musb_hdrc: Search and replace bBulkSplit with bulk_split Tony Lindgren
2007-08-13 13:49                                                           ` [PATCH 30/52] musb_hdrc: Search and replace bBulkCombine with bulk_combine Tony Lindgren
2007-08-13 13:49                                                             ` [PATCH 31/52] musb_hdrc: Search and replace bAddress with address Tony Lindgren
2007-08-13 13:49                                                               ` [PATCH 32/52] musb_hdrc: Search and replace bTestModeValue with test_mode_nr Tony Lindgren
2007-08-13 13:49                                                                 ` [PATCH 33/52] musb_hdrc: Search and replace bTestMode with test_mode Tony Lindgren
2007-08-13 13:49                                                                   ` [PATCH 34/52] musb_hdrc: Search and replace pGadgetDriver with gadget_driver Tony Lindgren
2007-08-13 13:49                                                                     ` [PATCH 35/52] musb_hdrc: Search and replace bDelayPortPowerOff with delay_port_power_off Tony Lindgren
2007-08-13 13:49                                                                       ` [PATCH 36/52] musb_hdrc: Search and replace pProcEntry with proc_entry Tony Lindgren
2007-08-13 13:49                                                                         ` [PATCH 37/52] musb_hdrc: Search and replace pPrivateData with private_data Tony Lindgren
2007-08-13 13:49                                                                           ` [PATCH 38/52] musb_hdrc: Search and replace dwMaxLength with max_len Tony Lindgren
2007-08-13 13:49                                                                             ` [PATCH 39/52] musb_hdrc: Search and replace dwActualLength with actual_len Tony Lindgren
2007-08-13 13:49                                                                               ` [PATCH 40/52] musb_hdrc: Search and replace bStatus with status Tony Lindgren
2007-08-13 13:49                                                                                 ` Tony Lindgren [this message]
2007-08-13 13:49                                                                                   ` [PATCH 42/52] musb_hdrc: Search and replace bMode with mode Tony Lindgren
2007-08-13 13:49                                                                                     ` [PATCH 43/52] musb_hdrc: Search and replace MGC_pfDmaProgramChannel with dma_program_channel Tony Lindgren
2007-08-13 13:49                                                                                       ` [PATCH 44/52] musb_hdrc: Search and replace pControlRequest with ctrlrequest Tony Lindgren
2007-08-13 13:49                                                                                         ` [PATCH 45/52] musb_hdrc: Search and replace bResult with result Tony Lindgren
2007-08-13 13:49                                                                                           ` [PATCH 46/52] musb_hdrc: Search and replace bSetAddress with set_address Tony Lindgren
2007-08-13 13:49                                                                                             ` [PATCH 47/52] musb_hdrc: Search and replace bRecip with recip Tony Lindgren
2007-08-13 13:49                                                                                               ` [PATCH 48/52] musb_hdrc: Search and replace pRequest with request Tony Lindgren
2007-08-13 13:49                                                                                                 ` [PATCH 49/52] musb_hdrc: Search and replace wCsrVal with csr Tony Lindgren
2007-08-13 13:49                                                                                                   ` [PATCH 50/52] musb_hdrc: Search and replace bTx with tx Tony Lindgren
2007-08-13 13:49                                                                                                     ` [PATCH 51/52] musb_hdrc: Search and replace wPacketSize with packet_sz Tony Lindgren
2007-08-13 13:49                                                                                                       ` [PATCH 52/52] musb_hdrc: Search and replace channelNum with chnum Tony Lindgren
2007-08-14  9:23         ` [PATCH 4/52] musb_hdrc: Search and replace pEnd with musb_ep when struct musb_hw_ep Tony Lindgren
2007-08-13 13:58 ` (no subject) Felipe Balbi
2007-08-14  8:06 ` musb CaMeLcAsEnOmOre (was: (no subject)) David Brownell
2007-08-14  8:55   ` Tony Lindgren

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=11870130793168-git-send-email-tony@atomide.com \
    --to=tony@atomide.com \
    --cc=linux-omap-open-source@linux.omap.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox